diff --git a/wp-admin/includes/ajax-actions.php b/wp-admin/includes/ajax-actions.php
index 6a197c7..b6bd757 100644
--- a/wp-admin/includes/ajax-actions.php
+++ b/wp-admin/includes/ajax-actions.php
@@ -2980,7 +2980,7 @@ function wp_ajax_parse_embed() {
 			$styles .= sprintf( '<link rel="stylesheet" href="%s"/>', $style );
 		}
 
-		$html = apply_shortcodes( $parsed );
+		$html = do_shortcode( $parsed );
 
 		global $wp_scripts;
 		if ( ! empty( $wp_scripts ) ) {
@@ -3037,7 +3037,7 @@ function wp_ajax_parse_media_shortcode() {
 		setup_postdata( $post );
 	}
 
-	$parsed = apply_shortcodes( $shortcode  );
+	$parsed = do_shortcode( $shortcode  );
 
 	if ( empty( $parsed ) ) {
 		wp_send_json_error( array(
diff --git a/wp-includes/default-filters.php b/wp-includes/default-filters.php
index 40ec96a..3402e48 100644
--- a/wp-includes/default-filters.php
+++ b/wp-includes/default-filters.php
@@ -430,7 +430,7 @@ add_action( 'template_redirect', 'redirect_canonical' );
 add_action( 'template_redirect', 'wp_redirect_admin_locations', 1000 );
 
 // Shortcodes
-add_filter( 'the_content', 'apply_shortcodes', 11 ); // AFTER wpautop()
+add_filter( 'the_content', 'do_shortcode', 11 ); // AFTER wpautop()
 
 // Media
 add_action( 'wp_playlist_scripts', 'wp_playlist_scripts' );
diff --git a/wp-includes/deprecated.php b/wp-includes/deprecated.php
index 618e680..48f0173 100644
--- a/wp-includes/deprecated.php
+++ b/wp-includes/deprecated.php
@@ -3758,24 +3758,3 @@ function wp_embed_handler_googlevideo( $matches, $attr, $url, $rawattr ) {
 
 	return '';
 }
-
-/**
- * Search content for shortcodes and filter shortcodes through their hooks.
- *
- * If there are no shortcode tags defined, then the content will be returned
- * without any filtering. This might cause issues when plugins are disabled but
- * the shortcode will still show up in the post or content.
- *
- * @since 2.5.0
- *
- * @global array $shortcode_tags List of shortcode tags and their callback hooks.
- *
- * @param string $content Content to search for shortcodes.
- * @param bool $ignore_html When true, shortcodes inside HTML elements will be skipped.
- * @return string Content with shortcodes filtered out.
- */
-function do_shortcode( $content, $ignore_html = false ) {
-	_deprecated_function( __FUNCTION__, '4.7.0', 'apply_shortcodes' );
-
-	return apply_shortcodes( $content, $ignore_html );
-}
\ No newline at end of file
diff --git a/wp-includes/media.php b/wp-includes/media.php
index 71fa14d..fd3bf43 100644
--- a/wp-includes/media.php
+++ b/wp-includes/media.php
@@ -1571,10 +1571,10 @@ function img_caption_shortcode( $attr, $content = null ) {
 
 	if ( $html5 ) {
 		$html = '<figure ' . $atts['id'] . $style . 'class="' . esc_attr( $class ) . '">'
-		. apply_shortcodes( $content ) . '<figcaption class="wp-caption-text">' . $atts['caption'] . '</figcaption></figure>';
+		. do_shortcode( $content ) . '<figcaption class="wp-caption-text">' . $atts['caption'] . '</figcaption></figure>';
 	} else {
 		$html = '<div ' . $atts['id'] . $style . 'class="' . esc_attr( $class ) . '">'
-		. apply_shortcodes( $content ) . '<p class="wp-caption-text">' . $atts['caption'] . '</p></div>';
+		. do_shortcode( $content ) . '<p class="wp-caption-text">' . $atts['caption'] . '</p></div>';
 	}
 
 	return $html;
diff --git a/wp-includes/class-wp-embed.php b/wp-includes/class-wp-embed.php
index a20bb3a..a8ce4d6 100644
--- a/wp-includes/class-wp-embed.php
+++ b/wp-includes/class-wp-embed.php
@@ -48,7 +48,7 @@ class WP_Embed {
 	 *
 	 * Since the [embed] shortcode needs to be run earlier than other shortcodes,
 	 * this function removes all existing shortcodes, registers the [embed] shortcode,
 	 * calls apply_shortcodes(), and then re-registers the old shortcodes.
 	 *
 	 * @global array $shortcode_tags
 	 *
@@ -65,7 +65,7 @@ class WP_Embed {
 		add_shortcode( 'embed', array( $this, 'shortcode' ) );
 
 		// Do the shortcode (only the [embed] one is registered)
-		$content = apply_shortcodes( $content, true );
+		$content = do_shortcode( $content, true );
 
 		// Put the original shortcodes back
 		$shortcode_tags = $orig_shortcode_tags;
@@ -124,7 +124,7 @@ class WP_Embed {
 	}
 
 	/**
-	 * The allby_shortcodes() callback function.
+	 * The do_shortcode() callback function.
 	 *
 	 * Attempts to convert a URL into embed HTML. Starts by checking the URL against the regex of
 	 * the registered embed handlers. If none of the regex matches and it's enabled, then the URL
@@ -48,7 +48,7 @@ class WP_Embed {
 	 * Since the [embed] shortcode needs to be run earlier than other shortcodes,
 	 * this function removes all existing shortcodes, registers the [embed] shortcode,
-	 * calls apply_shortcodes(), and then re-registers the old shortcodes.
+	 * calls do_shortcode(), and then re-registers the old shortcodes.
 	 *
 	 * @global array $shortcode_tags
diff --git a/wp-includes/shortcodes.php b/wp-includes/shortcodes.php
index e6bd9c4..b2aad3d 100644
--- a/wp-includes/shortcodes.php
+++ b/wp-includes/shortcodes.php
@@ -21,7 +21,7 @@
  *
  * To apply shortcode tags to content:
  *
- *     $out = apply_shortcodes( $content );
+ *     $out = do_shortcode( $content );
  *
  * @link https://codex.wordpress.org/Shortcode_API
  *
@@ -199,7 +199,7 @@ function has_shortcode( $content, $tag ) {
  * @param bool $ignore_html When true, shortcodes inside HTML elements will be skipped.
  * @return string Content with shortcodes filtered out.
  */
-function apply_shortcodes( $content, $ignore_html = false ) {
+function do_shortcode( $content, $ignore_html = false ) {
 	global $shortcode_tags;
 
 	if ( false === strpos( $content, '[' ) ) {
@@ -292,7 +292,7 @@ function get_shortcode_regex( $tagnames = null ) {
 }
 
 /**
  * Regular Expression callable for apply_shortcodes() for calling shortcode hook.
  * @see get_shortcode_regex for details of the match array contents.
  *
  * @since 2.5.0
@@ -292,7 +292,7 @@ function get_shortcode_regex( $tagnames = null ) {
 
 /**
- * Regular Expression callable for apply_shortcodes() for calling shortcode hook.
+ * Regular Expression callable for do_shortcode() for calling shortcode hook.
  * @see get_shortcode_regex for details of the match array contents.
  *
